@@ -13,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.api import config_change_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.api.servicemanagement.v1",
@@ -41,15 +39,21 @@ class ManagedService(proto.Message):
     Attributes:
         service_name (str):
             The name of the service. See the
-            `overview </service-management/overview>`__ for naming
-            requirements.
+            `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+            for naming requirements.
         producer_project_id (str):
             ID of the project that produces and owns this
             service.
     """
 
-    service_name = proto.Field(proto.STRING, number=2,)
-    producer_project_id = proto.Field(proto.STRING, number=3,)
+    service_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    producer_project_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class OperationMetadata(proto.Message):
@@ -91,13 +95,34 @@ class OperationMetadata(proto.Message):
                 The status code.
         """
 
-        description = proto.Field(proto.STRING, number=2,)
-        status = proto.Field(proto.ENUM, number=4, enum="OperationMetadata.Status",)
+        description = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        status = proto.Field(
+            proto.ENUM,
+            number=4,
+            enum="OperationMetadata.Status",
+        )
 
-    resource_names = proto.RepeatedField(proto.STRING, number=1,)
-    steps = proto.RepeatedField(proto.MESSAGE, number=2, message=Step,)
-    progress_percentage = proto.Field(proto.INT32, number=3,)
-    start_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
+    resource_names = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    steps = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=Step,
+    )
+    progress_percentage = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class Diagnostic(proto.Message):
@@ -118,9 +143,19 @@ class Diagnostic(proto.Message):
         WARNING = 0
         ERROR = 1
 
-    location = proto.Field(proto.STRING, number=1,)
-    kind = proto.Field(proto.ENUM, number=2, enum=Kind,)
-    message = proto.Field(proto.STRING, number=3,)
+    location = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    kind = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Kind,
+    )
+    message = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ConfigSource(proto.Message):
@@ -138,8 +173,15 @@ class ConfigSource(proto.Message):
             a service configuration (``google.api.Service``).
     """
 
-    id = proto.Field(proto.STRING, number=5,)
-    files = proto.RepeatedField(proto.MESSAGE, number=2, message="ConfigFile",)
+    id = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    files = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message="ConfigFile",
+    )
 
 
 class ConfigFile(proto.Message):
@@ -165,9 +207,19 @@ class ConfigFile(proto.Message):
         FILE_DESCRIPTOR_SET_PROTO = 4
         PROTO_FILE = 6
 
-    file_path = proto.Field(proto.STRING, number=1,)
-    file_contents = proto.Field(proto.BYTES, number=3,)
-    file_type = proto.Field(proto.ENUM, number=4, enum=FileType,)
+    file_path = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    file_contents = proto.Field(
+        proto.BYTES,
+        number=3,
+    )
+    file_type = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=FileType,
+    )
 
 
 class ConfigRef(proto.Message):
@@ -180,7 +232,10 @@ class ConfigRef(proto.Message):
             name}/configs/{config id}".
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ChangeReport(proto.Message):
@@ -199,7 +254,9 @@ class ChangeReport(proto.Message):
     """
 
     config_changes = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=config_change_pb2.ConfigChange,
+        proto.MESSAGE,
+        number=1,
+        message=config_change_pb2.ConfigChange,
     )
 
 
@@ -297,7 +354,7 @@ class Rollout(proto.Message):
             }
 
         Attributes:
-            percentages (Sequence[google.cloud.servicemanagement_v1.types.Rollout.TrafficPercentStrategy.PercentagesEntry]):
+            percentages (Mapping[str, float]):
                 Maps service configuration IDs to their
                 corresponding traffic percentage. Key is the
                 service configuration ID, Value is the traffic
@@ -305,7 +362,11 @@ class Rollout(proto.Message):
                 the sum must equal to 100.0.
         """
 
-        percentages = proto.MapField(proto.STRING, proto.DOUBLE, number=1,)
+        percentages = proto.MapField(
+            proto.STRING,
+            proto.DOUBLE,
+            number=1,
+        )
 
     class DeleteServiceStrategy(proto.Message):
         r"""Strategy used to delete a service. This strategy is a
@@ -314,17 +375,40 @@ class Rollout(proto.Message):
 
         """
 
-    rollout_id = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    created_by = proto.Field(proto.STRING, number=3,)
-    status = proto.Field(proto.ENUM, number=4, enum=RolloutStatus,)
+    rollout_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    created_by = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    status = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum=RolloutStatus,
+    )
     traffic_percent_strategy = proto.Field(
-        proto.MESSAGE, number=5, oneof="strategy", message=TrafficPercentStrategy,
+        proto.MESSAGE,
+        number=5,
+        oneof="strategy",
+        message=TrafficPercentStrategy,
     )
     delete_service_strategy = proto.Field(
-        proto.MESSAGE, number=200, oneof="strategy", message=DeleteServiceStrategy,
+        proto.MESSAGE,
+        number=200,
+        oneof="strategy",
+        message=DeleteServiceStrategy,
+    )
+    service_name = proto.Field(
+        proto.STRING,
+        number=8,
     )
-    service_name = proto.Field(proto.STRING, number=8,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
